@@ -97,13 +97,14 @@ class SatelliteSerializer(serializers.ModelSerializer):
     citation = serializers.SerializerMethodField()
     associated_satellites = serializers.SerializerMethodField()
     operator = serializers.SerializerMethodField()
+    is_frequency_violator = serializers.SerializerMethodField()
 
     class Meta:
         model = Satellite
         fields = (
             'sat_id', 'norad_cat_id', 'name', 'names', 'image', 'status', 'decayed', 'launched',
             'deployed', 'website', 'operator', 'countries', 'telemetries', 'updated', 'citation',
-            'associated_satellites'
+            'is_frequency_violator', 'associated_satellites'
         )
 
     @extend_schema_field(OpenApiTypes.STR)
@@ -184,12 +185,17 @@ class SatelliteSerializer(serializers.ModelSerializer):
 
     @extend_schema_field(OpenApiTypes.OBJECT)
     def get_associated_satellites(self, obj):
-        """Returns Satellite decayed datetime"""
+        """Returns Satellite IDs that are associated with the Satellite"""
         return [
             merged_satellite.satellite_identifier.sat_id
             for merged_satellite in obj.associated_with.all()
         ]
 
+    @extend_schema_field(OpenApiTypes.BOOL)
+    def get_is_frequency_violator(self, obj):
+        """Returns if there is a frequency violation"""
+        return obj.has_bad_transmitter
+
 
 class TransmitterEntrySerializer(serializers.ModelSerializer):
     """SatNOGS DB TransmitterEntry API Serializer"""
@@ -246,6 +252,7 @@ class TransmitterSerializer(serializers.ModelSerializer):
     uplink_mode = serializers.SerializerMethodField()
     alive = serializers.SerializerMethodField()
     updated = serializers.DateTimeField(source='reviewed')
+    frequency_violation = serializers.SerializerMethodField()
 
     class Meta:
         model = Transmitter
@@ -253,7 +260,7 @@ class TransmitterSerializer(serializers.ModelSerializer):
             'uuid', 'description', 'alive', 'type', 'uplink_low', 'uplink_high', 'uplink_drift',
             'downlink_low', 'downlink_high', 'downlink_drift', 'mode', 'mode_id', 'uplink_mode',
             'invert', 'baud', 'sat_id', 'norad_cat_id', 'status', 'updated', 'citation', 'service',
-            'iaru_coordination', 'iaru_coordination_url', 'itu_notification'
+            'iaru_coordination', 'iaru_coordination_url', 'itu_notification', 'frequency_violation'
         )
 
     # Keeping alive field for compatibility issues
@@ -302,6 +309,11 @@ class TransmitterSerializer(serializers.ModelSerializer):
         except AttributeError:
             return None
 
+    @extend_schema_field(OpenApiTypes.BOOL)
+    def get_frequency_violation(self, obj):
+        """Returns if there is a frequency violation"""
+        return obj.bad_transmitter
+
 
 @extend_schema_serializer(
     examples=[
@@ -457,7 +469,7 @@ class TelemetrySerializer(serializers.ModelSerializer):
 
     @extend_schema_field(OpenApiTypes.OBJECT)
     def get_associated_satellites(self, obj):
-        """Returns Satellite decayed datetime"""
+        """Returns Satellite IDs that are associated with the Satellite"""
         satellite = obj.satellite
         if satellite.associated_satellite:
             satellite = satellite.associated_satellite
