@@ -1,5 +1,6 @@
 """SatNOGS DB API django rest framework Views"""
 from django.conf import settings
+from django.core.cache import cache
 from django.core.files.base import ContentFile
 from django.db.models import F
 from django.shortcuts import get_object_or_404
@@ -17,6 +18,8 @@ from db.api import filters, pagination, serializers
 from db.api.parsers import JSONLDParser
 from db.api.perms import IsAuthenticatedOrOptions, SafeMethodsWithPermission
 from db.api.renderers import BrowserableJSONLDRenderer, JSONLDRenderer
+from db.api.throttling import GetTelemetryAnononymousRateThrottle, GetTelemetryUserRateThrottle, \
+    GetTelemetryViolatorThrottle
 from db.base.helpers import gridsquare
 from db.base.models import SATELLITE_STATUS, SERVICE_TYPE, TRANSMITTER_STATUS, TRANSMITTER_TYPE, \
     Artifact, DemodData, LatestTleSet, Mode, Satellite, SatelliteEntry, SatelliteIdentifier, \
@@ -520,9 +523,45 @@ class TelemetryViewSet(  # pylint: disable=R0901,R0912,R0915
     serializer_class = serializers.TelemetrySerializer
     filterset_class = filters.TelemetryViewFilter
     permission_classes = [SafeMethodsWithPermission]
+    throttle_classes = [
+        GetTelemetryAnononymousRateThrottle, GetTelemetryUserRateThrottle,
+        GetTelemetryViolatorThrottle
+    ]
     parser_classes = (FormParser, MultiPartParser, FileUploadParser)
     pagination_class = pagination.LinkedHeaderPageNumberPagination
 
+    def list(self, request, *args, **kwargs):
+        """
+        Lists data from satellite if they are filtered by NORAD ID or Satellite ID. Also logs the
+        requests if it is set to do so.
+        """
+        satellite = request.query_params.get('satellite', None)
+        sat_id = request.query_params.get('sat_id', None)
+
+        if not (satellite or sat_id):
+            data = {
+                'detail': (
+                    'For getting data please use either satellite(NORAD ID) filter or'
+                    'sat_id(Satellite ID) filter'
+                ),
+                'results': None
+            }
+            response = Response(data, status=status.HTTP_400_BAD_REQUEST)
+            response.exception = True
+            return response
+
+        if settings.LOG_TELEMETRY_REQUESTS:
+            user_id = str(request.user.id)
+            remote_address = str(request.META.get("REMOTE_ADDR"))
+            x_forwarded_for = str(request.META.get("HTTP_X_FORWARDED_FOR"))
+            timestamp = now().isoformat()
+            request_data = user_id + ';' + remote_address + ';' + x_forwarded_for + ';' + timestamp
+            cache.set(
+                'telemetry_log_' + user_id + '_' + timestamp, request_data,
+                settings.TELEMETRY_LOGS_TIME_TO_LIVE
+            )
+        return super().list(request, *args, **kwargs)
+
     @extend_schema(
         responses={'201': None},  # None
     )
