@@ -376,11 +376,37 @@ class Satellite(models.Model):
 
         :returns: bool
         """
-        bad_transmitter_count = 0
+        violation = cache.get("violator_" + self.satellite_identifier.sat_id)
+
+        if violation is not None:
+            return violation['status']
+
+        result = False
+
         for transmitter in Transmitter.objects.filter(satellite=self.id).exclude(status='invalid'):
             if transmitter.bad_transmitter:
-                bad_transmitter_count += 1
-        return bad_transmitter_count > 0
+                result = True
+                break
+        cache.set(
+            "violator_" + str(self.satellite_entry.norad_cat_id), {
+                'status': result,
+                'id': str(self.id)
+            }, None
+        )
+        cache.set(
+            "violator_" + self.satellite_identifier.sat_id, {
+                'status': result,
+                'id': str(self.id)
+            }, None
+        )
+        for merged_satellite in self.associated_with.all():
+            cache.set(
+                "violator_" + merged_satellite.satellite_identifier.sat_id, {
+                    'status': result,
+                    'id': str(self.id)
+                }, None
+            )
+        return result
 
 
 class TransmitterEntry(models.Model):
