@@ -265,6 +265,11 @@ def transmitter_suggestion_handler(request):
     transmitter = get_object_or_404(TransmitterSuggestion, pk=request.POST['pk'])
     if request.user.has_perm('base.approve_transmittersuggestion'):
         if 'approve' in request.POST:
+            # Force re-checking of bad transmitters be removing permanent cache
+            cache.delete("violator_" + str(transmitter.satellite.satellite_entry.norad_cat_id))
+            cache.delete("violator_" + transmitter.satellite.satellite_identifier.sat_id)
+            for merged_satellite in transmitter.satellite.associated_with.all():
+                cache.delete("violator_" + merged_satellite.satellite_identifier.sat_id)
             transmitter.approved = True
             messages.success(request, ('Transmitter approved.'))
         elif 'reject' in request.POST:
@@ -313,6 +318,7 @@ def search(request):
             Q(satellite_entry__name__icontains=query_string)
             | Q(satellite_entry__names__icontains=query_string)
             | Q(satellite_entry__norad_cat_id__icontains=query_string)
+            | Q(satellite_entry__norad_follow_id__icontains=query_string)
             | Q(satellite_identifier__sat_id__icontains=query_string)
             | Q(associated_with__satellite_identifier__sat_id__icontains=query_string)
         ).order_by('satellite_entry__name').prefetch_related(
