@@ -286,6 +286,17 @@ REST_FRAMEWORK = {
     ],
     'DEFAULT_FILTER_BACKENDS': ('django_filters.rest_framework.DjangoFilterBackend', ),
     'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema',
+    'DEFAULT_THROTTLE_RATES': {
+        'get_telemetry_anon': config(
+            'DEFAULT_THROTTLE_RATE_GET_TELEMETRY_ANON', default='6/minute'
+        ),
+        'get_telemetry_user': config(
+            'DEFAULT_THROTTLE_RATE_GET_TELEMETRY_USER', default='6/minute'
+        ),
+        'get_telemetry_violator': config(
+            'DEFAULT_THROTTLE_RATE_GET_TELEMETRY_VIOLATOR', default='1/day'
+        ),
+    }
 }
 
 SPECTACULAR_SETTINGS = {
@@ -474,6 +485,10 @@ SPACE_TRACK_PASSWORD = config('SPACE_TRACK_PASSWORD', default='')
 # Exported Frames
 EXPORTED_FRAMESET_TIME_TO_LIVE = config('EXPORTED_FRAMESET_TIME_TO_LIVE', default=21600, cast=int)
 
+# Keep Telemetry requests logs
+LOG_TELEMETRY_REQUESTS = config('LOG_TELEMETRY_REQUESTS', default=True, cast=bool)
+TELEMETRY_LOGS_TIME_TO_LIVE = config('TELEMETRY_LOGS_TIME_TO_LIVE', default=259200, cast=int)
+
 # Influx DB for decoded data_id
 USE_INFLUX = config('USE_INFLUX', default=False, cast=bool)
 INFLUX_HOST = config('INFLUX_HOST', default='localhost')
