@@ -141,12 +141,21 @@ $(document).ready(function () {
         copyToClipboard(text, el);
     });
 
+    let modal_open = false;
     // Update Satellite
     $('.update-satellite-link').each(function () {
         $(this).modalForm({
             formURL: $(this).data('form-url'),
             modalID: '#update-satellite-modal'
         });
+
+        $('#update-satellite-modal').on('hidden.bs.modal', function () {
+            modal_open = false;
+        });
+    
+        $('#update-satellite-modal').on('show.bs.modal', function () {
+            modal_open = true;
+        });
     });
 
     // Update Transmitter
@@ -155,6 +164,14 @@ $(document).ready(function () {
             formURL: $(this).data('form-url'),
             modalID: '#update-transmitter-modal'
         });
+
+        $('#update-transmitter-modal').on('hidden.bs.modal', function () {
+            modal_open = false;
+        });
+    
+        $('#update-transmitter-modal').on('show.bs.modal', function () {
+            modal_open = true;
+        });
     });
 
     // New transmitter links
@@ -163,6 +180,23 @@ $(document).ready(function () {
             formURL: $(this).data('form-url'),
             modalID: '#create-transmitter-modal'
         });
+
+        $('#create-transmitter-modal').on('hidden.bs.modal', function () {
+            modal_open = false;
+        });
+    
+        $('#create-transmitter-modal').on('show.bs.modal', function () {
+            modal_open = true;
+        });
+    });
+
+    // Prevent navigate to new url if a modal is open
+    $(window).on('beforeunload', function() {
+        if (modal_open === true) {
+            return true;
+        }
+
+        return undefined;
     });
 
     // Ask for help in a toast if this Satellite object is flagged as in need
